View Source Notifiex.Notification (Notifiex v1.2.0)
Module for notifications.
Link to this section Summary
Functions
send_notification sends the notification with the help of the notification tuple.
Link to this section Functions
@spec send_notification(Notifiex.config(), Notifiex.send_type()) :: Notifiex.result()
send_notification sends the notification with the help of the notification tuple.
notification should have the following:
- Service: Slack, etc.
- Payload
- Options